import * as React from 'react';
import Dialog from '@material-ui/core/Dialog';
import DialogActions from '@material-ui/core/DialogActions';
import DialogContent from '@material-ui/core/DialogContent';
import DialogTitle from '@material-ui/core/DialogTitle';
import * as classnames from 'classnames';

export interface Props {
	header?: React.ReactNode;
	content?: React.ReactNode;
	actions?: React.ReactNode;
	onClose?: React.ReactEventHandler;
	visible: boolean;
	dialogClass?: string;
	maxWidth?: number;
}

class DialogMessage extends React.Component<Props> {
	shouldComponentUpdate(nextProps: Props): boolean {
		return (
			this.props.visible !== nextProps.visible ||
			this.props.header !== nextProps.header ||
			this.props.actions !== nextProps.actions ||
			this.props.content !== nextProps.content
		);
	}

	render(): React.ReactNode {
		return <Dialog className={classnames('dialog', this.props.dialogClass)} open={this.props.visible} onClose={this.props.onClose} aria-labelledby="alert-dialog-title" aria-describedby="alert-dialog-description">
			{this.props.header && <DialogTitle className="dialog-title" id="alert-dialog-title">{this.props.header}</DialogTitle>}
			{this.props.content && <DialogContent className="dialog-content">{this.props.content}</DialogContent>}
			{this.props.actions && <DialogActions className="dialog-actions">{this.props.actions}</DialogActions>}
		</Dialog>;
	}
}

export default DialogMessage;
