import * as React from 'react';
import * as classnames from 'classnames';
import Tooltip from '@material-ui/core/Tooltip';
import BaggageIcon from '@material-ui/icons/BusinessCenter';

import Segment from '../../schemas/Segment';
import { i18n } from '../../i18n';
import { pluralize } from '../../utils';
import { FeaturePayment } from '../../schemas/FareFamilyFeature';

export interface Props {
	segment: Segment;
}

export class BaggageInfo extends React.Component<Props> {
	render(): React.ReactNode {
		const baggage = this.props.segment.luggage;
		const baggageFromFamily = this.props.segment.baggageFromFamily;

		let	measurementLabel = '',
			baggageLabel = '',
			tooltipText = '',
			tooltip: React.ReactNode = '',
			noBaggage = false;

		if (baggageFromFamily) {
			noBaggage = baggageFromFamily.needToPay !== FeaturePayment.Free;
			baggageLabel = noBaggage ? i18n('baggage-paid-segment') : baggageFromFamily.value;
			tooltipText = baggageFromFamily.description;
		}
		else {
			if (baggage && baggage.value > 0) {
				if (baggage.measurement === 'pc') {
					measurementLabel = pluralize(baggage.value, 'baggage-measurement__pc_1', 'baggage-measurement__pc_2', 'baggage-measurement__pc_3');
				}
				else {
					measurementLabel = 'baggage-measurement__' + baggage.measurement;
				}

				baggageLabel = `${baggage.value} ${i18n(measurementLabel)}`;
				tooltipText = baggage.text;
			}
			else {
				noBaggage = true;
				baggageLabel = i18n('baggage-paid-segment');
			}
		}

		if (noBaggage || tooltipText) {
			tooltip = <span className="tooltip">{noBaggage ? i18n('baggage-paid-tooltip') : tooltipText}</span>;
		}

		return <Tooltip title={tooltip} placement="top">
			<div className={classnames('flight-details-segment-baggage', {'flight-details-segment-baggage_noBaggage': noBaggage})}>
				<span className="flight-details-segment-baggage__icon">
					<BaggageIcon/>
				</span>

				<span className="flight-details-segment-baggage__label">
					{baggageLabel}
				</span>
			</div>
		</Tooltip>;
	}
}
