import * as React from 'react';
import Flight from '../../models/Flight';
import { ReactNode } from 'react';
import { i18n } from '../../i18n';
import Button from '@material-ui/core/Button/Button';
import { AdvancedFlightInfo } from '../../schemas/SelectedFlight';
import { pluralize } from '../../utils';
import PricingInfo from './ProDetails/PricingInfo';
import { RootState } from '../../store/reducers';
import { connect } from 'react-redux';
import autobind from 'autobind-decorator';
import Error from '@material-ui/icons/Error';
import Tooltip from '@material-ui/core/Tooltip/Tooltip';
import { getNemoURL } from '../../store/config/selectors';
import { PriceDebug } from './ProDetails/PriceDebug';
import Money from '../../schemas/Money';
import Price from '../ConnectedPrice';
import { getAdvancedInfoByFlights } from '../../store/selectors';
import { AdvancedFlightInfoByFlights } from '../../schemas/PricingInfo';

export interface OwnProps {
	flight: Flight;
	replacedFlightInfo: AdvancedFlightInfo;
	totalPrice: Money;
}

interface State {
	detailsIsOpen: boolean;
}

interface StateProps {
	nemoURL: string;
	advancedInfoByFlights: AdvancedFlightInfoByFlights;
}

class ProDetails extends React.Component<OwnProps & StateProps, State> {
	state: State = {
		detailsIsOpen: false
	};

	tooltipClass = {
		tooltip: 'flight-details-advanced-item__tooltip'
	};

	shouldComponentUpdate(nextProps: OwnProps & StateProps, nextState: State): boolean {
		return this.props.flight !== nextProps.flight ||
			this.props.advancedInfoByFlights !== nextProps.advancedInfoByFlights ||
			this.state.detailsIsOpen !== nextState.detailsIsOpen;
	}

	renderActionDetails(): ReactNode {
		return <Button onClick={this.priceInfoPopupToggle}>
			{i18n('results-flight-priceDetails-popup__close')}
		</Button>;
	}

	@autobind
	priceInfoPopupToggle(): void {
		this.setState({
			detailsIsOpen: !this.state.detailsIsOpen
		});
	}

	render(): React.ReactNode {
		const { flight, nemoURL, advancedInfoByFlights } = this.props,
			advancedFlightInfo = advancedInfoByFlights[flight.id],
			ticketsNumberLabel = pluralize(advancedFlightInfo.expectedNumberOfTickets, 'results-flight-tickets_1', 'results-flight-tickets_2', 'results-flight-tickets_3');

		return <div className="flight-details-advanced">
			<div className="flight-details-advanced__left">
				{advancedFlightInfo.expectedNumberOfTickets > 0 && <div className="flight-details-advanced-item flight-details-advanced-item__tickets">
					<span>{`${advancedFlightInfo.expectedNumberOfTickets} ${i18n(ticketsNumberLabel)}`}</span>

					<Tooltip classes={this.tooltipClass} title={i18n('results-flight-tickets__warning')}>
						<Error/>
					</Tooltip>
				</div>}

				{advancedFlightInfo.pricingInfo.subagentProfit && <div className="flight-details-advanced-item flight-details-advanced-item__subagentProfit">
					<span>{i18n('results-flight-priceDetails__subagentProfit')}</span>

					<Price price={advancedFlightInfo.pricingInfo.subagentProfit}/>
				</div>}
			</div>

			<div className="flight-details-advanced__right">
				{advancedFlightInfo.pricingDebugLinks.length > 0 && <div className="flight-details-advanced-item flight-details-advanced-pricingDebug">
					<PriceDebug nemoURL={nemoURL} pricingDebugLinks={advancedFlightInfo.pricingDebugLinks}/>
				</div>}

				<div className="flight-details-advanced-item flight-details-advanced-item__priceInfo">
					<Button onClick={this.priceInfoPopupToggle}>
						{i18n('results-flight-priceDetails-popup__header')}
					</Button>
				</div>
			</div>

			<PricingInfo
				totalPrice={this.props.totalPrice ? this.props.totalPrice : flight.totalPrice}
				isOpen={this.state.detailsIsOpen}
				onClose={this.priceInfoPopupToggle}
				pricingInfo={advancedFlightInfo.pricingInfo}
				renderActionBlock={this.renderActionDetails()}/>
		</div>;
	}
}

const mapStateToProps = (state: RootState): StateProps => {
	return {
		nemoURL: getNemoURL(state),
		advancedInfoByFlights: getAdvancedInfoByFlights(state)
	};
};

export default connect(mapStateToProps)(ProDetails);
