import { PricingDebugLink } from '../../../schemas/PricingInfo';
import * as React from 'react';
import Button from '@material-ui/core/Button/Button';
import DialogMessage from '../../DialogMessage';
import autobind from 'autobind-decorator';
import { i18n } from '../../../i18n';
import { trimSlashes } from '../../../utils';

export interface Props {
	nemoURL: string;
	pricingDebugLinks: PricingDebugLink[];
}

interface State {
	popupIsOpened: boolean
}

export class PriceDebug extends React.Component<Props, State> {
	state: State = {
		popupIsOpened: false
	};

	renderPricingDebugItem(info: PricingDebugLink, index: number): React.ReactNode {
		const { nemoURL } = this.props;

		return <div className="flight-details-advanced-priceDebug__item" key={index}>
			<div className="flight-details-advanced-priceDebug__route">{info.route}</div>

			<Button className="flight-details-advanced-priceDebug__link" href={`${trimSlashes(nemoURL)}${trimSlashes(info.link)}`}>{info.text}</Button>
		</div>;
	}

	renderPricingDebugList(): React.ReactNode {
		const { pricingDebugLinks } = this.props;

		return <div className="flight-details-advanced-priceDebug">
			{pricingDebugLinks.map((pricingDebug, index) => {
				return this.renderPricingDebugItem(pricingDebug, index);
			})}
		</div>;
	}

	@autobind
	popupToggle(): void {
		this.setState({
			popupIsOpened: !this.state.popupIsOpened
		});
	}

	render(): React.ReactNode {
		const { pricingDebugLinks, nemoURL } = this.props;

		if (pricingDebugLinks.length === 1) {
			return (
				<Button href={`${trimSlashes(nemoURL)}/${trimSlashes(pricingDebugLinks[0].link)}`}>
					{pricingDebugLinks[0].text}
				</Button>
			);
		}
		else {
			return <>
				<Button onClick={this.popupToggle}>{i18n('results-flight-pricingDebug__header')}</Button>

				<DialogMessage
					visible={this.state.popupIsOpened}
					header={i18n('results-flight-priceDetails-popup__header')}
					content={this.renderPricingDebugList()}
					onClose={this.popupToggle}
				/>
			</>;
		}
	}
}
