import * as React from 'react';
import { ReactNode } from 'react';
import * as classnames from 'classnames';
import { i18n } from '../../../i18n';
import Price from '../../ConnectedPrice';
import DialogMessage from '../../DialogMessage';
import { Fare } from '../../../schemas/PricingInfo';
import Money from '../../../schemas/Money';
import { PricingInfo as PricingInfoModel } from '../../../schemas/PricingInfo';

export interface Props {
	isOpen: boolean;
	renderActionBlock: ReactNode;
	onClose: React.ReactEventHandler;
	totalPrice: Money;
	pricingInfo: PricingInfoModel;
}

class PricingInfo extends React.Component<Props> {
	shouldComponentUpdate(nextProps: Props): boolean {
		return this.props.isOpen !== nextProps.isOpen ||
			this.props.renderActionBlock !== nextProps.renderActionBlock ||
			this.props.pricingInfo !== nextProps.pricingInfo;
	}

	renderPriceDetailsItem(item: Fare, index?: number): React.ReactNode {
		const passengerType = i18n(`results-flight-priceDetails__passengerType_${item.type}`);

		return <div className="flight-details-advanced-priceItem" key={index}>
			<div className="flight-details-advanced-priceItem__count">
				{`${passengerType}: ${item.count}`}
			</div>

			<div className="flight-details-advanced-priceItem__price">
				<div className="flight-details-advanced-tax flight-details-advanced-tax__mainFare">
					<div className="flight-details-advanced-tax__name flight-details-advanced-tax__name_bottom">
						{i18n('results-flight-priceDetails__mainTariff')}
					</div>

					<div className="flight-details-advanced-tax__value">
						<Price price={item.baseFare}/>
					</div>
				</div>

				{item.taxesArray.length ? <div className="flight-details-advanced-taxes">
					<div className="flight-details-advanced-taxes__label">
						{i18n('results-flight-priceDetails__taxesBlock')}
					</div>

					{item.taxesArray.map((tax, index) => {
						return <div className={classnames('flight-details-advanced-tax', `flight-details-advanced-tax_${tax.code}`)} key={index}>
							<div className="flight-details-advanced-tax__name">{tax.code}</div>

							<div className="flight-details-advanced-tax__value"><Price price={tax.price}/></div>
						</div>;
					})}
				</div> : null}
			</div>

			<div className="flight-details-advanced-priceItem__summary">
				<Price price={item.totalFare}/>
			</div>
		</div>;
	}

	renderAgencyCharge(): React.ReactNode {
		const { pricingInfo } = this.props;

		return <div className="flight-details-advanced-priceItem flight-details-advanced-priceItem_charge">
			<div>
				{i18n('results-flight-priceDetails__charges')}:
			</div>

			<div className="flight-details-advanced-tax__value">
				<Price price={pricingInfo.agencyCharge}/>
			</div>
		</div>;
	}

	renderTotalPrice(): React.ReactNode {
		const { totalPrice } = this.props;

		return <div className="flight-details-advanced-priceItem flight-details-advanced-priceItem_summary">
			<div>
				{i18n('results-flight-priceDetails__totalPrice')}:
			</div>

			<div className="flight-details-advanced-tax__value">
				<Price price={totalPrice}/>
			</div>
		</div>;
	}

	renderPriceDetails(): React.ReactNode {
		const { pricingInfo } = this.props;

		return <div className="flight-details-advanced__priceInfo">
			{pricingInfo.fares.map((item, index) => this.renderPriceDetailsItem(item, index))}
			{this.renderAgencyCharge()}
			{this.renderTotalPrice()}
		</div>;
	}

	render(): React.ReactNode {
		return <DialogMessage
			visible={this.props.isOpen}
			header={i18n('results-flight-priceDetails-popup__header')}
			content={this.renderPriceDetails()}
			actions={this.props.renderActionBlock}
			onClose={this.props.onClose}
		/>;
	}
}

export default PricingInfo;
