import * as React from 'react';
import * as moment from 'moment';
import Tooltip from '@material-ui/core/Tooltip';

import Flight from '../../models/Flight';
import { i18n } from '../../i18n';

interface Props {
	flight: Flight;
	isOpen: boolean;
}

class RouteInfo extends React.Component<Props> {
	shouldComponentUpdate(nextProps: Props): boolean {
		return (
			this.props.flight.id !== nextProps.flight.id ||
			this.props.isOpen !== nextProps.isOpen
		);
	}

	render(): React.ReactNode {
		const flight = this.props.flight;
		const firstSegment = flight.firstSegment;
		const lastSegment = this.props.isOpen ? firstSegment : flight.lastSegment;
		const arrivalAtNextDay = firstSegment.depDate.date() !== lastSegment.arrDate.date();
		const arrivalAtNextDayTitle = arrivalAtNextDay ? <span className="tooltip">{i18n('results-flight-nextDayArrival').replace('[%-date-%]', lastSegment.arrDate.format('DD MMMM'))}</span> : '';
		const time = this.props.isOpen ?
			moment.duration(firstSegment.flightTime, 'seconds').format(`d [${i18n('utils-dates-d')}] h [${i18n('utils-dates-h')}] m [${i18n('utils-dates-m')}]`) :
			flight.totalFlightTimeHuman;

		return <>
			<div className="flight-summary-stage flight-summary-stage_departure">
				<div className="flight-summary-stage__time">
					{firstSegment.depDate.format('HH:mm')}
				</div>

				<div className="flight-summary-stage__location" title={firstSegment.depAirport.name}>
					{firstSegment.depAirport.IATA}
				</div>
			</div>

			<div className="flight-summary-stage-routeInfo">
				<div className="flight-summary-stage-routeInfo__arrow"/>
				<span className="flight-summary-stage-routeInfo__flightTime">{time}</span>
			</div>

			<div className="flight-summary-stage flight-summary-stage_arrival">
				{arrivalAtNextDay ? (
					<Tooltip title={arrivalAtNextDayTitle} placement="top">
						<div className="flight-summary-stage__time flight-summary-stage__time_warning">
							{lastSegment.arrDate.format('HH:mm')}
						</div>
					</Tooltip>
				) : (
					<div className="flight-summary-stage__time">
						{lastSegment.arrDate.format('HH:mm')}
					</div>
				)}

				<div className="flight-summary-stage__location" title={lastSegment.arrAirport.name}>
					{lastSegment.arrAirport.IATA}
				</div>
			</div>
		</>;
	}
}

export default RouteInfo;
