import { SET_CONFIG } from './actions';
import { Currency, Language } from '../../enums';
import CurrencyRates from '../../schemas/CurrencyRates';
import I18nPool from '../../schemas/I18nPool';
import { trimSlashes } from '../../utils';
import { ComponentProps } from '@nemo.travel/search-widget';
import { handleAction } from 'redux-actions';

export interface Config {
	rootElement: HTMLElement;
	nemoURL?: string;
	locale?: Language;
	// http://frontend.mlsd.ru/api/system/info/currencyRates
	currencyRates?: CurrencyRates;
	defaultCurrency?: Currency;
	proMode: boolean;
	i18n?: I18nPool;
	searchForm?: ComponentProps;
}

const initalConfig: Config = {
	rootElement: document.getElementById('root'),
	nemoURL: 'http://frontend.mlsd.ru',
	currencyRates: {},
	defaultCurrency: Currency.RUB,
	proMode: false,
	i18n: {},
	locale: Language.English,
	searchForm: {}
};

export const configReducer = handleAction(SET_CONFIG, (state, action) => {
	const newConfig = { ...state, ...action.payload };

	newConfig.nemoURL = trimSlashes(newConfig.nemoURL) + '/';

	return newConfig;
}, initalConfig);
