import {
	FilterAirportsAction,
	ADD_AIRPORT,
	REMOVE_AIRPORT,
	REMOVE_ALL_AIRPORTS
} from './actions';
import { addCodeInList, removeCodeFromList } from '../../../utils';
import { LocationType } from '../../../enums';

export interface AirportsFilterState {
	[LocationType.Arrival]: string[];
	[LocationType.Departure]: string[];
}

const initialAirportsFiltersState: AirportsFilterState = {
	[LocationType.Departure]: [],
	[LocationType.Arrival]: []
};

const airportsCodesListReducer = (state: string[], action: FilterAirportsAction): string[] => {
	switch (action.type) {
		case ADD_AIRPORT:
			return addCodeInList(state, action.payload.IATA);

		case REMOVE_AIRPORT:
			return removeCodeFromList(state, action.payload.IATA);
	}

	return state;
};

export const airportsFilterReducer = (state: AirportsFilterState = initialAirportsFiltersState, action: FilterAirportsAction): AirportsFilterState => {
	switch (action.type) {
		case REMOVE_ALL_AIRPORTS:
			return { ...state, departure: [], arrival: []};
	}

	if (action.payload) {
		return { ...state, [action.payload.locationType]: airportsCodesListReducer(state[action.payload.locationType], action) };
	}

	return initialAirportsFiltersState;
};
