import { ADD_TIME_INTERVAL, REMOVE_TIME_INTERVAL, REMOVE_ALL_TIME_INTERVALS, FilterTimeAction } from './actions';
import { addCodeInList, removeCodeFromList } from '../../../utils';
import { FlightTimeInterval, LocationType } from '../../../enums';

export interface TimeFilterState {
	[LocationType.Arrival]: FlightTimeInterval[];
	[LocationType.Departure]: FlightTimeInterval[];
}

const initialTimeFiltersState: TimeFilterState = {
	[LocationType.Departure]: [],
	[LocationType.Arrival]: []
};

const timesListReducer = (state: string[], action: FilterTimeAction): string[] => {
	switch (action.type) {
		case ADD_TIME_INTERVAL:
			return addCodeInList(state, action.payload.timeInterval);

		case REMOVE_TIME_INTERVAL:
			return removeCodeFromList(state, action.payload.timeInterval);
	}

	return state;
};

export const timeFilterReducer = (state: TimeFilterState = initialTimeFiltersState, action: FilterTimeAction): TimeFilterState => {
	switch (action.type) {
		case REMOVE_ALL_TIME_INTERVALS:
			return { ...state, departure: [], arrival: []};
	}

	if (action.payload) {
		return { ...state, [action.payload.locationType]: timesListReducer(state[action.payload.locationType], action) };
	}

	return initialTimeFiltersState;
};
