import {
	ADD_FLIGHTS,
	CLEAR_FLIGHTS,
	FlightsAction,
	FlightsActionPayload,
	REMOVE_FLIGHTS,
	RemoveFlightsAction
} from './actions';
import Flight from '../../models/Flight';
import { handleActions } from 'redux-actions';

export interface FlightsState {
	[flightId: string]: Flight;
}

export const flightsReducer = handleActions<FlightsState, FlightsActionPayload>({
	[CLEAR_FLIGHTS]: () => ({}),
	[ADD_FLIGHTS]: (state: FlightsState, { payload }: FlightsAction) => {
		const newFlightsPool: FlightsState = { ...state };

		payload.forEach(flight => newFlightsPool[flight.id] = flight);

		return newFlightsPool;
	},
	[REMOVE_FLIGHTS]: (state: FlightsState, { payload }: RemoveFlightsAction) => {
		const removeMap: { [flightId: string]: boolean } = {};
		const result: FlightsState = {};

		payload.forEach(flightId => removeMap[flightId] = true);

		for (const flightId in state) {
			if (state.hasOwnProperty(flightId) && !removeMap.hasOwnProperty(flightId)) {
				result[flightId] = state[flightId];
			}
		}

		return result;
	}
}, {});
