import { call, put, select, takeEvery } from 'redux-saga/effects';
import { GO_TO_BOOKING, GoToBookingAction } from '../actions';
import createOrder from '../../services/requests/createOrder';
import { batchActions } from '../batching/actions';
import { setProblemType } from '../actualization/problem/actions';
import { ActualizationProblem } from '../actualization/problem/reducers';
import { setInfo } from '../actualization/info/actions';
import { stopLoadingActualization } from '../isLoadingActualization/actions';
import { getNemoURL } from '../config/selectors';

function* worker({ payload }: GoToBookingAction) {
	const nemoURL: string = yield select(getNemoURL);
	const orderLink = yield call(<any>createOrder, payload.flightIds, nemoURL);

	if (!orderLink) {
		return yield put(batchActions(
			setProblemType(ActualizationProblem.Unknown),
			setInfo([]),
			stopLoadingActualization()
		));
	}

	window.location.href = `${nemoURL}${orderLink}`;
}

export default function* goToBookingSaga() {
	yield takeEvery(GO_TO_BOOKING, worker);
}
