const path = require('path');
const webpack = require('webpack');
const Extract = require('mini-css-extract-plugin');
const packageJSON = require('./package.json');

const moduleName = 'results';
const isDevMode = process.env.NODE_ENV === 'development';

const extractSass = new Extract({
	filename: `${moduleName}.css`
});

module.exports = {
	context: __dirname,
	entry: './src/main.tsx',
	output: {
		path: path.resolve(__dirname, 'dist'),
		publicPath: '/',
		filename: `${moduleName}.js`,
		library: 'FlightsResultsWidget'
	},
	performance: {
		hints: false
	},
	resolve: {
		modules: [
			'node_modules',
			path.resolve(__dirname, 'src'),
			path.resolve(__dirname, 'dist')
		],
		extensions: ['.ts', '.js', '.json', '.tsx', '.css', '.scss']
	},
	module: {
		rules: [
			{
				test: /\.tsx?$/,
				loader: 'ts-loader',
				include: [
					path.resolve(__dirname, 'src')
				],
				exclude: [
					path.resolve(__dirname, 'node_modules')
				]
			},
			{
				test: /\.scss$/,
				include: [
					path.resolve(__dirname, 'src/css')
				],
				use: [
					Extract.loader,
					{
						loader: 'css-loader',
						options: {
							minimize: !isDevMode
						}
					},
					'resolve-url-loader',
					'postcss-loader',
					'sass-loader'
				],
			},
			{
				test: /\.(svg|png)$/,
				loader: 'url-loader',
				include: [
					path.resolve(__dirname, 'src/css/images')
				],
				options: {
					publicPath: '',
					outputPath: '',
					name: '/[name].[ext]'
				}
			}
		]
	},
	plugins: [
		extractSass,
		new webpack.DefinePlugin({
			'process.env': {
				NODE_ENV: JSON.stringify(isDevMode ? 'development' : 'production'),
				VERSION: JSON.stringify(packageJSON.version)
			}
		})
	]
};
